const express = require('express');
const bodyParser = require('body-parser');
const path = require('path');
const morgan = require('morgan');
const axios = require('axios');

class ApiProxy {
  constructor(options = {}) {
    this.setting = Object.assign(
      {
        api: 'http://127.0.0.1:7001',
      },
      options,
    );
    this.app = null;
    this.createServer(this.setting);
  }

  ruan() {
    const { host = '127.0.0.1', port = 8888 } = this.setting;
    this.app.listen(port, host, (err) => {
      if (err) {
        console.log('启动服务器失败', err);
        return;
      }
      console.log(`成功开启开发服务器:http://${host}:${port}`);
    });
  }

  createServer(cfg = {}) {
    this.app = express();
    this.app.use(morgan('dev'));
    this.app.use(bodyParser.json()); // for parsing application/json
    this.app.use(bodyParser.urlencoded({ extended: true })); // for parsing application/x-www-form-urlencoded

    this.app.all('/api/*', (req, res) => {
      const method = req.method.toLocaleUpperCase();
      let params = req.query;
      const { api = '', timeout = 5000 } = cfg;
      let url = '';
      if (api.indexOf('http') > -1 || api.indexOf('https') > -1) {
        url =
          api.substring(api.length - 1) === '/'
            ? api.substring(0, api.length - 1)
            : api;
      } else {
        url = api;
      }
      url += `${req.path}`;
      let reqHeaders = {};
      if (req.headers.cookie) {
        reqHeaders['Cookie'] = req.headers.cookie;
      }
      console.log(`请求API:${url}`);
      const reqOps = {
        url,
        method,
        headers: reqHeaders,
        params: params || {},
        timeout: timeout,
        withCredentials: true,
      };

      if (method === 'POST') {
        reqOps.data = Object.assign({}, params, req.body);
      }

      axios
        .request(reqOps)
        .then((result) => {
          const resCookie = result.headers['set-cookie'];
          if (resCookie) {
            res.setHeader('set-cookie', resCookie.join(';'));
          }
          return res.send(result.data);
        })
        .catch((err) => {
          const { status, statusText, headers = {} } = err.response || {};
          return res.send({ statusText, status, headers });
        });
    });
  }
}

module.exports = ApiProxy;
